@@ -3,13 +3,15 @@ from .utils import exceptions, helpers, headers
 
 from os import system as s
 from colored import fore
+from json import loads
+from requests import get
 
 __title__ = 'nz-ua.py'
 __author__ = 'Xsarz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2023 Xsarz'
-__version__ = '1.0'
-__newest__ = __version__
+__version__ = '1.0.1'
+__newest__ = loads(get("https://pypi.org/pypi/nz-ua.py/json").text)["info"]["version"]
 
 
 if __version__ != __newest__:
